@@ -23,6 +23,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>BorderRadiusHeaderView</name>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CheckImageResultWidget</name>
     <message>
@@ -111,7 +118,11 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>%1 (%2)</source>
+        <source>Community</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Professional</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -245,10 +256,6 @@
 </context>
 <context>
     <name>InitialWidget</name>
-    <message>
-        <source>Deepin Upgrade</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Current version: V%1</source>
         <translation></translation>
@@ -257,10 +264,6 @@
         <source>Take a few simple steps to upgrade your system to</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Deepin 23</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Pre-Check</source>
         <translation></translation>
@@ -303,6 +306,14 @@
         <source>I have read and agreed to the &lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt; and &lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;.</source>
         <translation></translation>
     </message>
+    <message>
+        <source>System Upgrade Tool</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>deepin 23</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -428,6 +439,17 @@
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>SoftwareEvaluationOfflineWidget</name>
+    <message>
+        <source>Software Evaluation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your current usage scenario is in a state of no network. We cannot evaluate the software you are using. After the upgrade is complete, the software you are currently installing needs to be reinstalled. If you want to view the details of the applications that can be installed for the upgrade, please upgrade online</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SoftwareEvaluationWidget</name>
     <message>
@@ -438,13 +460,21 @@
         <source>The upgrade may take a long time. Please plug in to avoid interruption.</source>
         <translation></translation>
     </message>
+    <message>
+        <source>The system upgrade will ensure the integrity of user data, and we will not delete user data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The cross-version upgrade does not migrate the application. After the upgrade is completed, it supports automatic installation of the selected compatible application</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Compatible Apps</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Incompatible Apps</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -481,14 +511,6 @@
         <source>Clean data disk</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>System backup only, no app backup</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Less disk space is required if enabled, but some apps may not work properly after restoring the system from version 23.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>SystemUpgradeWidget</name>
@@ -512,6 +534,14 @@
         <source>Restoration failed</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>After clicking restart, the system will be upgraded, please save the current running application data before confirming</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Restart now</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpgradeCheckProgressWidget</name>
