@@ -23,6 +23,13 @@
         <translation>系统升级前需要为您备份，请耐心等待</translation>
     </message>
 </context>
+<context>
+    <name>BorderRadiusHeaderView</name>
+    <message>
+        <source>All</source>
+        <translation>全选</translation>
+    </message>
+</context>
 <context>
     <name>CheckImageResultWidget</name>
     <message>
@@ -65,6 +72,37 @@
         <translation>正在检查镜像完整性...</translation>
     </message>
 </context>
+<context>
+    <name>CheckResultType</name>
+    <message>
+        <source>%1 (%2)</source>
+        <translation type="obsolete">%1 (%2)</translation>
+    </message>
+    <message>
+        <source>Too old</source>
+        <translation type="obsolete">版本过低</translation>
+    </message>
+    <message>
+        <source>Activated</source>
+        <translation type="obsolete">已激活</translation>
+    </message>
+    <message>
+        <source>Unactivated</source>
+        <translation type="obsolete">未激活</translation>
+    </message>
+    <message>
+        <source>Requirement: %1 GB</source>
+        <translation type="obsolete">基线要求：%1 GB</translation>
+    </message>
+    <message>
+        <source>Data disk %1 GB / %2 GB</source>
+        <translation type="obsolete">数据盘 %1 GB/%2 GB</translation>
+    </message>
+    <message>
+        <source>System disk %1 GB / %2 GB</source>
+        <translation type="obsolete">系统盘 %1 GB/%2 GB</translation>
+    </message>
+</context>
 <context>
     <name>CheckSizeThread</name>
     <message>
@@ -116,7 +154,7 @@
     </message>
     <message>
         <source>%1 (%2)</source>
-        <translation>%1 (%2)</translation>
+        <translation type="vanished">%1 (%2)</translation>
     </message>
     <message>
         <source>Too old</source>
@@ -142,6 +180,14 @@
         <source>System disk %1 GB / %2 GB</source>
         <translation>系统盘 %1 GB/%2 GB</translation>
     </message>
+    <message>
+        <source>Community</source>
+        <translation>社区版</translation>
+    </message>
+    <message>
+        <source>Professional</source>
+        <translation>专业版</translation>
+    </message>
 </context>
 <context>
     <name>DBusWorker</name>
@@ -251,7 +297,7 @@
     <name>InitialWidget</name>
     <message>
         <source>Deepin Upgrade</source>
-        <translation>Deepin系统升级</translation>
+        <translation type="vanished">Deepin系统升级</translation>
     </message>
     <message>
         <source>Current version: V%1</source>
@@ -263,10 +309,10 @@
     </message>
     <message>
         <source>Deepin 23</source>
-        <translation>Deepin 23</translation>
+        <translation type="vanished">Deepin 23</translation>
     </message>
     <message>
-        <source>I have read and agreed to the</source>
+        <source>I have read and agreed to the </source>
         <translation type="vanished">我已阅读并同意</translation>
     </message>
     <message>
@@ -330,6 +376,14 @@
         <source>I have read and agreed to the &lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt; and &lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;.</source>
         <translation>我已阅读并同意&lt;a href=&quot;user&quot; style=&quot;text-decoration: none;&quot;&gt;%1&lt;/a&gt;和&lt;a href=&quot;privacy&quot; style=&quot;text-decoration: none;&quot;&gt;%2&lt;/a&gt;。</translation>
     </message>
+    <message>
+        <source>System Upgrade Tool</source>
+        <translation>系统升级工具</translation>
+    </message>
+    <message>
+        <source>deepin 23</source>
+        <translation>deepin 23</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -463,6 +517,17 @@
         <translation>评估已安装软件在新系统中的兼容性</translation>
     </message>
 </context>
+<context>
+    <name>SoftwareEvaluationOfflineWidget</name>
+    <message>
+        <source>Software Evaluation</source>
+        <translation>软件评估</translation>
+    </message>
+    <message>
+        <source>Your current usage scenario is in a state of no network. We cannot evaluate the software you are using. After the upgrade is complete, the software you are currently installing needs to be reinstalled. If you want to view the details of the applications that can be installed for the upgrade, please upgrade online</source>
+        <translation>您当前的使用场景处于无网络状态，我们无法对你正在使用的软件进行评估，升级完成后您当前所安装的软件需要重新进行安装，如需查看升级可安装应用详情请联网升级</translation>
+    </message>
+</context>
 <context>
     <name>SoftwareEvaluationWidget</name>
     <message>
@@ -489,6 +554,26 @@
         <source>Incompatible Apps</source>
         <translation>不兼容应用</translation>
     </message>
+    <message>
+        <source>V23 version supports applications</source>
+        <translation type="vanished">V23版本支持应用</translation>
+    </message>
+    <message>
+        <source>The V23 version does not support the application</source>
+        <translation type="vanished">V23版本不支持应用</translation>
+    </message>
+    <message>
+        <source>The system upgrade will ensure the integrity of user data, and we will not delete user data</source>
+        <translation>系统升级会保证用户数据的完整性，我们不会对用户数据进行删减</translation>
+    </message>
+    <message>
+        <source>By default, the cross-version upgrade does not migrate the installed applications. After the upgrade is completed, the system will automatically install the selected applications in the list. Please select the software that needs to be installed after the upgrade is complete</source>
+        <translation type="vanished">跨版本升级默认不对已安装应用进行迁移，完成升级后系统会对列表勾选应用进行自动化安装，请选择升级完成后需要安装的应用</translation>
+    </message>
+    <message>
+        <source>The cross-version upgrade does not migrate the application. After the upgrade is completed, it supports automatic installation of the selected compatible application</source>
+        <translation>跨版本升级不对应用进行迁移，升级完成后支持对已勾选兼容应用自动化安装</translation>
+    </message>
 </context>
 <context>
     <name>StorageResultWidget</name>
@@ -526,11 +611,11 @@
     </message>
     <message>
         <source>System backup only, no app backup</source>
-        <translation>仅备份系统，不备份应用</translation>
+        <translation type="vanished">仅备份系统，不备份应用</translation>
     </message>
     <message>
         <source>Less disk space is required if enabled, but some apps may not work properly after restoring the system from version 23.</source>
-        <translation>开启此功能将降低备份空间要求，但从V23还原至当前系统时，部分应用可能不可用</translation>
+        <translation type="vanished">开启此功能将降低备份空间要求，但从V23还原至当前系统时，部分应用可能不可用</translation>
     </message>
 </context>
 <context>
@@ -555,6 +640,14 @@
         <source>Restoration failed</source>
         <translation>还原失败</translation>
     </message>
+    <message>
+        <source>After clicking restart, the system will be upgraded, please save the current running application data before confirming</source>
+        <translation>点击重启后系统将进行升级，确认前请对当前运行应用数据进行保存</translation>
+    </message>
+    <message>
+        <source>Restart now</source>
+        <translation>立即重启</translation>
+    </message>
 </context>
 <context>
     <name>UpgradeCheckProgressWidget</name>
